EMComposition
=============

.. container:: related

    *Related*

    * `AutodiffComposition`
    * `Composition_Learning`
    * `EpisodicMemoryMechanism`
    * `ContentAddressableMemory`

.. automodule:: psyneulink.library.compositions.emcomposition
   :members:
   :private-members:
   :exclude-members: Parameters, execute
